##  Migration Process
The migration process includes the following steps:
  1. Create an IdP configuration in SAP LeanIX.
  2. Configure the IdP side with Entity ID, Reply URL, and the required attributes and claims.
  3. Configure attribute mappings if you plan to manage user roles in your IdP.
  4. Upload metadata from your IdP to SAP LeanIX.
  5. Test the configuration in an incognito or private browser.
  6. If the test is successful, enable the IdP.
  7. Repeat for each workspace.
